@@ -6,6 +6,7 @@ import logging
 from datetime import datetime
 import random
 import string
+from inspect import getframeinfo, stack
 
 logger = logging.getLogger(__name__)
 
@@ -40,28 +41,29 @@ if __name__ == '__main__':
     exit(0)
 
 
-def FixMsg(msg):
+def FixMsg(msg, caller=None):
+
 
-    function = None
     stage = None
 
-    if 'CurrentFunctionForLogging' in Shared:
-        function = Shared.CurrentFunctionForLogging
-
     if 'CurrentStageForLogging' in Shared:
         stage = Shared.CurrentStageForLogging
 
-    if len(function) > 0:
-        fn = function[-1].__name__
-    else:
-        fn = 'None'
-
     if stage:
         sid = stage.spec.id
     else:
         sid = 'None'
 
-    msg = f'{sid}\t{fn}\t{msg}'
+    if caller:
+        funcName = caller.function
+        fileName = caller.filename
+        lineNum = caller.lineno
+    else:
+        funcName = 'None'
+        fileName = 'None'
+        lineNum = 'None'
+
+    msg = f'{sid}\t{funcName}\t{msg}\t{fileName}\t{lineNum}'
     return msg
 
 
@@ -75,17 +77,19 @@ def LogException(msg='An error occurred.'):
         msg (str, optional): Error message. Defaults to 'An error occurred.'.
     """
 
+    caller = getframeinfo(stack()[1][0])
+
     stage = Shared.CurrentStageForLogging
     if stage:
         stageStr = JsonDumps(stage)
         logger.error(f'{stageStr}')
-        msg = FixMsg(f'{msg}')
+        msg = FixMsg(msg=f'{msg}', caller=caller)
 
     logger.exception(msg)
     raise Exception(msg)
 
 
-def LogOptionalPrint(msg, level='INFO', file=None, doPrint=True):
+def LogOptionalPrint(msg, level='INFO', file=None, doPrint=True, caller=None):
     """Log a message at desired level and print it if needed.
 
     Note:
@@ -100,6 +104,9 @@ def LogOptionalPrint(msg, level='INFO', file=None, doPrint=True):
         doPrint (bool, optional): If the message should be printed too. Defaults to True.
     """
 
+    if not caller:
+        caller = getframeinfo(stack()[1][0])
+
     if file and not doPrint:
         LogException('Set doPrint to True when you pass the file argument.')
 
@@ -112,7 +119,7 @@ def LogOptionalPrint(msg, level='INFO', file=None, doPrint=True):
         else:
             file = sys.stdout
 
-    msg = FixMsg(msg)
+    msg = FixMsg(msg=f'{msg}', caller=caller)
 
     if doPrint:
         print(msg, file=file)
@@ -121,30 +128,10 @@ def LogOptionalPrint(msg, level='INFO', file=None, doPrint=True):
 
 
 def Log(msg, level='INFO'):
-    """Log a message at the desired level.
-
-    Note:
-        - If CurrentStageForLogging is set then stage.spec.id is added to message.
-
-    Args:
-        msg (str): To be loged and printed.
-        level (str, optional): Log level for the message. Defaults to 'INFO'.
-    """
-    LogOptionalPrint(msg, level, file=None, doPrint=False)
+    caller = getframeinfo(stack()[1][0])
+    LogOptionalPrint(msg, level, file=None, doPrint=False, caller=caller)
 
 
 def LogPrint(msg, level='INFO', file=None):
-    """Log a message at desired level and print it.
-
-    Note:
-        - If CurrentStageForLogging is set then stage.spec.id is added to message
-        - If file is not identified, it is chosen between based on the level.
-        - If level is CRITICAL or ERROR the stderr is chosen otherwise the message is printed on stdout.
-
-    Args:
-        msg (str): To be loged and printed.
-        level (str, optional): Log level for the message. Defaults to 'INFO'.
-        file (file, optional): Where the message is printed. Defaults to None.
-    """
-
-    LogOptionalPrint(msg, level, file, doPrint=True)
+    caller = getframeinfo(stack()[1][0])
+    LogOptionalPrint(msg, level, file, doPrint=True, caller=caller)
